#!/usr/bin/python3.6
#
# basic from chatterbot docs 
# extended by chrissie 08.2020
#

from chatterbot import ChatBot
from chatterbot.trainers import ListTrainer
import time
import random
import asyncio
import websockets

# Uncomment the following lines to enable verbose logging
# import logging
# logging.basicConfig(level=logging.INFO)

# Create a new chat bot
buddha = ChatBot('Buddha',
    storage_adapter='chatterbot.storage.SQLStorageAdapter',
    database_uri='sqlite:///buddha.sqlite3'
    )
confucius = ChatBot('Confucius',
    storage_adapter='chatterbot.storage.SQLStorageAdapter',
    database_uri='sqlite:///conficius.sqlite3'
    )
laotze = ChatBot('Laotze',
    storage_adapter='chatterbot.storage.SQLStorageAdapter',
    database_uri='sqlite:///laotze.sqlite3'
)

# read buddha, confucius, lao fortunes
b_lines = []
c_lines = []
l_lines = []
with open('./101buddhafortune.txt') as f:
    for curline in f:
        if not curline.startswith("%"):
            b_lines.append(curline.rstrip())

with open('./75-confucius-fortunes.txt') as g:
    for curline in g:
        if not curline.startswith("%"):
            c_lines.append(curline.rstrip())

with open('./190-lao-fortunes.txt') as h:
    for curline in h:
        if not curline.startswith("%"):
            l_lines.append(curline.rstrip())

#print ('\n'.join(map(str, l_lines)))
#print ('\n'.join(map(str, b_lines)))
#print ('\n'.join(map(str, c_lines)))

# do only training one time first run then change training
# training will be saved in db.sqlite3 in current directory
training = 0
if training == 1:
    # reset database - beware!
    buddha.storage.drop()
    confucius.storage.drop()
    laotze.storage.drop()

    buddha_trainer = ListTrainer(buddha)
    buddha_trainer.train (b_lines)

    confucius_trainer = ListTrainer(confucius)
    confucius_trainer.train (c_lines)

    laotze_trainer = ListTrainer(laotze)
    laotze_trainer.train (l_lines)
    exit (1)

# get initial random citication
c_count = len (c_lines)
c_rnd = random.randint(0, c_count)
c_rnd = c_rnd - 1

# get initial response
buddha_response = buddha.get_response(c_lines[c_rnd])
confucius_response = confucius.get_response(c_lines[c_rnd])
laotze_response = laotze.get_response(c_lines[c_rnd])

# simple test, each bot must respond differently
#print ("rnd: " + str(c_rnd))
#print ("in: " + c_lines[c_rnd])
#print (buddha_response)
#print (confucius_response)
#print (laotze_response)
#exit (1)

# https://chatterbot.readthedocs.io/en/stable/conversations.html

# new
async def philosoph_responses (websocket, path):
    global confucius_response
    global buddha_response
    global laotze_response

    async for message in websocket:
        print ("Guest says: " + str(message) + "\n")
        confucius_response = confucius.get_response(str(laotze_response) + " " + str(buddha_response) + " " + str(message))
        confucius_response2 = "+ Confucius says: " + str(confucius_response)
        print(confucius_response2 + "\n")
        time.sleep(1)
        await websocket.send (str(confucius_response2))

        buddha_response = buddha.get_response(str(confucius_response) + " " + str(laotze_response)+ " " + str(message))
        buddha_response2 = "! Buddha says: " + str(buddha_response)
        print(buddha_response2)
        time.sleep(1)
        await websocket.send (str(buddha_response2))

        laotze_response = laotze.get_response (str(buddha_response) + " " + str(confucius_response)+ " " + str(message))
        laotze_response2 = "# Laotze says: " + str(laotze_response)
        print(laotze_response2)
        time.sleep(1)
        await websocket.send (str(laotze_response2))

print ("Now binding to websocket ....:8080")
asyncio.get_event_loop().run_until_complete(
    websockets.serve(philosoph_responses, 'localhost', 8080))

asyncio.get_event_loop().run_forever()


